// $Id: ode_check.hpp 3804 2016-03-20 15:08:46Z bradbell $
# ifndef CPPAD_CPPAD_IPOPT_EXAMPLE_ODE_CHECK_HPP
# define CPPAD_CPPAD_IPOPT_EXAMPLE_ODE_CHECK_HPP
/* --------------------------------------------------------------------------
CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell

CppAD is distributed under multiple licenses. This distribution is under
the terms of the
                    GNU General Public License Version 3.

A copy of this license is included in the COPYING file of this distribution.
Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
-------------------------------------------------------------------------- */

extern bool ode_check(const SizeVector& N, const NumberVector& x);

# endif
